#ifndef YOUTUBEVIDEOSELECTIONWINDOW_H
#define YOUTUBEVIDEOSELECTIONWINDOW_H

#include "../base/enums.h"
#include <QWidget>
#include <QVariantMap>

class YouTubeVideoListModel;
class ListView;
class QMaemo5EditBar;
class QPushButton;
class QVBoxLayout;
class QModelIndex;

class YouTubeVideoSelectionWindow : public QWidget
{
    Q_OBJECT

public:
    explicit YouTubeVideoSelectionWindow(YouTubeVideoListModel *model, const QString &text, const char* slot, QWidget *parent);
    ~YouTubeVideoSelectionWindow();
    void positionAtIndex(const QModelIndex &index);

private slots:
    void onItemClicked(const QModelIndex &index);
    void onButtonClicked();
    void deleteVideosFromUploads();
    void addVideosToFavourites();
    void deleteVideosFromFavourites();
    void showPlaylistDialog();
    void addVideosToPlaylist(const QString &id);
    void addVideosToNewPlaylist(const QVariantMap &playlist);
    void deleteVideosFromPlaylist();
    void addVideosToWatchLaterPlaylist();
    void deleteVideosFromWatchLaterPlaylist();
    void addVideoDownloads();
    void addAudioDownloads();
    void queueVideos();

signals:
    void accepted();

private:
    YouTubeVideoListModel *m_model;
    ListView *m_listView;
    QMaemo5EditBar *m_editBar;
    QPushButton *m_acceptButton;
    QVBoxLayout *m_vbox;
};

#endif // YOUTUBEVIDEOSELECTIONWINDOW_H
